@@ -1,7 +1,7 @@
 test_that("optk_gcms works with kmeans and wss method", {
   var_names <- c("bio_1", "bio_12")
   s <- import_gcms(system.file("extdata", package = "chooseGCM"), var_names = var_names)
-  study_area <- terra::ext(c(-80, -30, -50, 10)) |> terra::vect(crs="epsg:4326")
+  study_area <- terra::ext(c(-80, -30, -50, 10)) |> terra::vect(crs="+proj=longlat +datum=WGS84 +no_defs")
   result <- optk_gcms(s, var_names, study_area, cluster = "kmeans", method = "wss")
   expect_no_error(result)
   expect_true(ggplot2::is_ggplot(result))
@@ -10,7 +10,7 @@ test_that("optk_gcms works with kmeans and wss method", {
 test_that("optk_gcms works with kmeans and silhouette method", {
   var_names <- c("bio_1", "bio_12")
   s <- import_gcms(system.file("extdata", package = "chooseGCM"), var_names = var_names)
-  study_area <- terra::ext(c(-80, -30, -50, 10)) |> terra::vect(crs="epsg:4326")
+  study_area <- terra::ext(c(-80, -30, -50, 10)) |> terra::vect(crs="+proj=longlat +datum=WGS84 +no_defs")
   result <- optk_gcms(s, var_names, study_area, cluster = "kmeans", method = "silhouette")
   expect_no_error(result)
   expect_true(ggplot2::is_ggplot(result))
@@ -19,13 +19,13 @@ test_that("optk_gcms works with kmeans and silhouette method", {
 test_that("optk_gcms fails with invalid cluster method", {
   var_names <- c("bio_1", "bio_12")
   s <- import_gcms(system.file("extdata", package = "chooseGCM"), var_names = var_names)
-  study_area <- terra::ext(c(-80, -30, -50, 10)) |> terra::vect(crs="epsg:4326")
+  study_area <- terra::ext(c(-80, -30, -50, 10)) |> terra::vect(crs="+proj=longlat +datum=WGS84 +no_defs")
   expect_error(optk_gcms(s, var_names, study_area, cluster = "invalid_method"), "Assertion on 'cluster' failed")
 })
 
 test_that("optk_gcms fails with invalid method", {
   var_names <- c("bio_1", "bio_12")
   s <- import_gcms(system.file("extdata", package = "chooseGCM"), var_names = var_names)
-  study_area <- terra::ext(c(-80, -30, -50, 10)) |> terra::vect(crs="epsg:4326")
+  study_area <- terra::ext(c(-80, -30, -50, 10)) |> terra::vect(crs="+proj=longlat +datum=WGS84 +no_defs")
   expect_error(optk_gcms(s, var_names, study_area, method = "invalid_method"), "Assertion on 'method' failed")
 })
